# Missing dependencies for tests
%bcond_with check

# Missing dependencies for documentation
%bcond_without doc

Name:           buildbot
Version:        3.10.1
Release:        %mkrel 1
Summary:        Build/test automation system
Group:          Development/Python
License:        GPLv2+
URL:            https://buildbot.net/

Source0:        %{pypi_source buildbot}
Source1:        %{pypi_source buildbot-worker}
Source2:        %{pypi_source buildbot-www}
Source3:        %{pypi_source buildbot-waterfall-view}
Source4:        %{pypi_source buildbot-grid-view}
Source5:        %{pypi_source buildbot-console-view}
# Build-time only component for buildbot
Source6:        %{pypi_source buildbot-pkg}
# Patch0:	        buildbot-req.patch
# Patch1:	        fix-build.patch
# Patch2:	        fix-buildbot-docs.patch
BuildArch:      noarch
# For making the build work from source
	
BuildRequires:  python3dist(setuptools) >= 21.2.1
BuildRequires:  python3dist(twisted) >= 17.9
BuildRequires:  python3dist(jinja2) >= 2.1
BuildRequires:  python3dist(zope.interface) >= 4.1.1
BuildRequires:  python3dist(future)
BuildRequires:  python3dist(sqlalchemy) >= 0.8
BuildRequires:  python3dist(sqlalchemy-migrate) >= 0.9
BuildRequires:  python3dist(python-dateutil) >= 1.5
BuildRequires:  python3dist(txaio) >= 2.2.2
BuildRequires:  python3dist(autobahn) >= 0.16
BuildRequires:  python3dist(pyjwt)	
BuildRequires:  python3dist(pyyaml)
BuildRequires:  python3dist(automat) >= 20.2

%if %{with docs}
BuildRequires:  python3dist(sphinx) >= 1.4
BuildRequires:  python3dist(sphinxcontrib-blockdiag)
BuildRequires:  python3dist(sphinxcontrib-spelling)
BuildRequires:  python3dist(pyenchant)
BuildRequires:  (python3dist(docutils) >= 0.8 with python3dist(docutils) < 0.13)
BuildRequires:  python3dist(sphinx-jinja)
BuildRequires:  python3dist(towncrier)
%endif

Requires:       %{name}-master >= %{version}
Requires:       python3dist(automat) >= 20.2


%description
The BuildBot is a system to automate the compile/test cycle required by
most software projects to validate code changes. By automatically
rebuilding and testing the tree each time something has changed, build
problems are pinpointed quickly, before other developers are
inconvenienced by the failure.

%package        master
Summary:        buildbot master
Group:          Development/Python
Requires:       python3-twisted >= 8.0.0
Requires:       python3-jinja2 >= 2.1
Requires:       python3-sqlalchemy
Requires:       python3-boto
Requires:       python3dist(treq)
Recommends:       %{name}-doc

%description    master
The BuildBot is a system to automate the compile/test cycle required by
most software projects to validate code changes. By automatically
rebuilding and testing the tree each time something has changed, build
problems are pinpointed quickly, before other developers are
inconvenienced by the failure.
This package contains only the buildmaster implementation.

%package worker
Summary:        Build/test automation system
Obsoletes:      %{name}-slave < 0.9.0
Provides:       %{name}-slave = %{version}-%{release}
 
	
%if ! %{with docs}
Obsoletes:      %{name}-doc < %{version}-%{release}
%endif
 
	
%description worker
This package contains only the buildworker implementation.
The buildbot-master package contains the buildmaster.
	
%package www
Summary:        Build/test automation system

# Script to get bundled js	
# cat \
# ./www/codeparameter/package.json \
# ./www/console_view/package.json	\
# ./www/base/package.json	\
# ./www/waterfall_view/package.json \
# ./www/data_module/package.json \
# ./www/grid_view/package.json \	
# | jq '.dependencies' | sed 's/[{}, ]//g' | sort -u

Provides:        bundled(guanlecoja) = 0.8.0
Provides:        bundled(guanlecoja) = 0.8.3
Provides:        bundled(gulp) = 3.9.0
Provides:        bundled(gulp) = 3.9.1
Provides:        bundled(gulp-shell) = 0.4.1
Provides:        bundled(http-proxy) = 1.11.1
Provides:        bundled(minimist) = 1.1.1
Provides:        bundled(shelljs) = 0.5.3

%description www
Provides web frontend for buildbot.



%package        doc
Group:          Development/Python
License:        GPLv2+
Summary:        BuildBot documentation
%description    doc
Buildbot documentation.

%prep
%setup -q -b0 -b1 -b2 -b3 -b4 -b4 -b5 -b6
%autopatch -p0

%build
%py3_build

%if %{with docs}
pushd docs
make docs.tgz VERSION="%{version}" SPHINXBUILD=sphinx-build-3
popd
%endif

pushd ../%{name}-worker-%{version}
%py3_build
popd

# For buildbot_pkg build-time module to set version correctly
export BUILDBOT_VERSION=%{version}

# So that other modules can use buildbot-pkg import
export PYTHONPATH=%{_builddir}/%{name}-%{version}/build/lib:%{_builddir}/%{name}-pkg-%{version}/build/lib

bbweb_components=(pkg www waterfall-view grid-view console-view)

for bbweb_component in ${bbweb_components[@]}; do
	pushd ../%{name}-${bbweb_component}-%{version}
	sed -e "s/^    setup_requires=.*$//" -i setup.py
	%py3_build
	popd
done

%install
%py3_install

mkdir -p %{buildroot}%{_datadir}/%{name}/ \
         %{buildroot}%{_mandir}/man1/ \
         %{buildroot}%{_docdir}/%{name}-%{version}

# For buildbot_pkg build-time module to set version correctly
export BUILDBOT_VERSION=%{version}

# So that other modules can use buildbot-pkg import
export PYTHONPATH=%{_builddir}/%{name}-%{version}/build/lib:%{_builddir}/%{name}-pkg-%{version}/build/lib

bbweb_components=(www waterfall-view grid-view console-view)

for bbweb_component in ${bbweb_components[@]}; do
	pushd ../%{name}-${bbweb_component}-%{version}
	%py3_install
	popd
done

install -Dpm0644 -t %{buildroot}%{_mandir}/man1 docs/buildbot.1

%if %{with docs}
mkdir -p %{buildroot}%{_pkgdocdir}
tar xf docs/docs.tgz --strip-components=1 -C %{buildroot}%{_pkgdocdir}
%endif

# install worker files
pushd ../%{name}-worker-%{version}
%py3_install
install -Dpm0644 -t %{buildroot}%{_mandir}/man1 docs/buildbot-worker.1
popd

# Purge windows-only files
rm -vf %{buildroot}%{_bindir}/*windows*

%if %{with check}
%check
trial buildbot.test
%endif

%files

%files          master
%doc %{_mandir}/man1/buildbot.1*
%doc COPYING CREDITS NEWS UPGRADING
%{_bindir}/buildbot
%{python3_sitelib}/buildbot
%{_datadir}/%{name}
%{python3_sitelib}/buildbot-*egg-info

%files worker
%doc NEWS UPGRADING
%license COPYING
%{_bindir}/buildbot-worker
%{_mandir}/man1/buildbot-worker.1*
%{python3_sitelib}/buildbot_worker/
%{python3_sitelib}/buildbot_worker-*egg-info/

%files www
%license COPYING
%{python3_sitelib}/buildbot_www/
%{python3_sitelib}/buildbot_www-*.egg-info/
%{python3_sitelib}/buildbot_waterfall_view/
%{python3_sitelib}/buildbot_waterfall_view-*egg-info/
%{python3_sitelib}/buildbot_grid_view/
%{python3_sitelib}/buildbot_grid_view-*egg-info/
%{python3_sitelib}/buildbot_console_view/
%{python3_sitelib}/buildbot_console_view-*egg-info/

%if %{with docs}
%files          doc
%{_docdir}/%{name}-%{version}
%endif


%changelog
* Sun Dec 31 2023 joequant <joequant> 3.10.1-1.mga10
+ Revision: 2024695
- update to 3.10.1 and py3.12

* Tue Oct 11 2022 neoclust <neoclust> 3.6.1-1.mga9
+ Revision: 1896254
- New version 3.6.1

* Sun Jul 10 2022 joequant <joequant> 3.5.0-1.mga9
+ Revision: 1868198
- update to 3.5.0

* Sun Apr 03 2022 umeabot <umeabot> 3.4.1-2.mga9
+ Revision: 1841220
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 joequant <joequant> 3.4.1-1.mga9
+ Revision: 1774623
- update to py3.10 and version 3.4.1

* Wed Nov 24 2021 joequant <joequant> 3.4.0-1.mga9
+ Revision: 1758951
- update to 3.4.0

* Sun Oct 03 2021 joequant <joequant> 3.3.0-1.mga9
+ Revision: 1748643
- update to 3.3.0

* Tue Jul 20 2021 joequant <joequant> 3.2.0-1.mga9
+ Revision: 1737136
- update to 3.2.0

* Wed Mar 31 2021 joequant <joequant> 3.0.2-2.mga9
+ Revision: 1712176
- add treq requires

* Sat Mar 20 2021 joequant <joequant> 3.0.2-1.mga9
+ Revision: 1705202
- update to 3.0.2

* Mon Mar 08 2021 joequant <joequant> 3.0.0-1.mga9
+ Revision: 1700749
- update to 3.0.0
- update to 2.10.1

* Thu Dec 10 2020 joequant <joequant> 2.9.2-1.mga8
+ Revision: 1655067
- update to 2.9.2

* Sun Dec 06 2020 joequant <joequant> 2.9.1-1.mga8
+ Revision: 1653663
- update to 2.9.1

* Thu May 21 2020 joequant <joequant> 2.7.0-2.mga8
+ Revision: 1586526
- update with www

* Tue May 19 2020 joequant <joequant> 2.7.0-1.mga8
+ Revision: 1586278
- update to 2.7.0

* Sun Feb 16 2020 umeabot <umeabot> 2.3.1-3.mga8
+ Revision: 1536201
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 tv <tv> 2.3.1-2.mga8
+ Revision: 1453696
- rebuild for python 3.8

* Fri Jul 19 2019 shlomif <shlomif> 2.3.1-1.mga8
+ Revision: 1423019
- New version 2.3.1

* Thu Apr 25 2019 joequant <joequant> 0.8.12-7.mga7
+ Revision: 1395233
- fix buildbot build with latest sphinx
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Fri May 27 2016 tv <tv> 0.8.12-3.mga6
+ Revision: 1018869
- patch 1: fix building with new sphinx

* Fri Feb 19 2016 umeabot <umeabot> 0.8.12-2.mga6
+ Revision: 969937
- Mageia 6 Mass Rebuild

* Thu Sep 24 2015 philippem <philippem> 0.8.12-1.mga6
+ Revision: 883389
- update to 0.8.12, fix build-req patch
- update to 0.8.12

* Sat Jul 25 2015 philippem <philippem> 0.8.10-1.mga6
+ Revision: 857596
- update to 0.8.10

* Wed Oct 15 2014 umeabot <umeabot> 0.8.9-5.mga5
+ Revision: 743841
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.8.9-4.mga5
+ Revision: 725986
- rebuild for missing pythoneggs deps

* Fri Sep 26 2014 tv <tv> 0.8.9-3.mga5
+ Revision: 725000
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 0.8.9-2.mga5
+ Revision: 678244
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Tue Jul 01 2014 philippem <philippem> 0.8.9-1.mga5
+ Revision: 641807
- update to 0.8.9

* Sat May 31 2014 pterjan <pterjan> 0.8.8-5.mga5
+ Revision: 628120
- Rebuild for new Python

* Mon Mar 17 2014 philippem <philippem> 0.8.8-4.mga5
+ Revision: 604499
- fix doc build

* Tue Oct 22 2013 umeabot <umeabot> 0.8.8-3.mga4
+ Revision: 542518
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 0.8.8-2.mga4
+ Revision: 497668
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 25 2013 philippem <philippem> 0.8.8-1.mga4
+ Revision: 471711
- update to 0.8.8

* Mon Jun 10 2013 philippem <philippem> 0.8.7p1-1.mga4
+ Revision: 441866
- adjust requires for python-dateutil
- adjust requires for python-dateutil

* Sat Jun 08 2013 philippem <philippem> 0.8.7p1-0.mga4
+ Revision: 440615
- upstream update and rebuild for python-dateutil dependency

* Fri Jan 11 2013 umeabot <umeabot> 0.8.7-3.mga3
+ Revision: 347220
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Sep 24 2012 fwang <fwang> 0.8.7-2.mga3
+ Revision: 296972
- correct list req

* Mon Sep 24 2012 fwang <fwang> 0.8.7-1.mga3
+ Revision: 296963
- new version 0.8.7

* Sat Sep 08 2012 philippem <philippem> 0.8.6p1-2.mga3
+ Revision: 290223
+ rebuild (emptylog)

* Tue Sep 04 2012 philippem <philippem> 0.8.6p1-1.mga3
+ Revision: 288103
- New upstream release

* Mon Oct 24 2011 philippem <philippem> 0.8.5-2.mga2
+ Revision: 157877
+ rebuild (emptylog)

* Mon Oct 24 2011 philippem <philippem> 0.8.5-1.mga2
+ Revision: 157742
- new upstream

* Tue Jul 12 2011 philippem <philippem> 0.8.4p1-3.mga2
+ Revision: 123055
+ rebuild (emptylog)

* Mon Jul 11 2011 philippem <philippem> 0.8.4p1-2.mga2
+ Revision: 122175
-fix require on python-sqlalchemy-migrate

* Mon Jul 04 2011 philippem <philippem> 0.8.4p1-1.mga2
+ Revision: 118139
- Update to 8.4
- add new requires (python-sqlalchemy)

* Sat Jun 11 2011 philippem <philippem> 0.8.3p1-1.mga2
+ Revision: 103857
-upstream update
-add master, slave and doc packages

* Thu Mar 17 2011 tv <tv> 0.8.0-3.mga1
+ Revision: 73377
- imported package buildbot

